---
sidebar_position: 6
---
# Why Web3 and What Are Fees?

At tgether, we leverage the power of Web3 to create a decentralized, transparent, and trustless platform for communities to achieve consensus. Let’s explore why Web3 is essential to our mission and why certain actions on the platform require fees.

## Why Web3?

In today’s world, the growing influence of AI and the control of content by centralized media entities have made it increasingly difficult for people to trust what they see and read. The core issue tgether seeks to address is how we can be confident that the information shared on the web is reliable and accurately represents the truth in its context. While tgether doesn’t aim to tackle the philosophical debate on “what is truth,” it leans on a proven model: reputation and peer review. By using blockchain as a datasource, tgether ensures that decisions and interactions are transparent, immutable, and driven by community consensus rather than centralized control.

- **Decentralized Data Storage:** All community interactions, proposals, and votes are stored on the blockchain, making them verifiable by anyone. This eliminates the need for a central entity to manage data, ensuring that all information is transparent and accessible.

- **Immutable Records:** Once data is recorded on the blockchain, it cannot be altered. This guarantees that the decisions made by the community are final and can be trusted by all members.

- **Trustless Arbitration:** All arbitration is handled by Chainlink Automation, which relies on a decentralized network of independent, unbiased operators (oracle network) to process proposals and submissions. Communities no longer need to depend on a central authority to enforce rules; instead, the rules are built directly into the code, and the results are verified by multiple neutral third parties.

## What Are Fees For?

To maintain a decentralized and trustless platform, certain actions on tgether require fees. These fees cover the operational costs of future processing, ensuring the platform remains sustainable and functional. Specifically, fees are charged for:

- **Creating a Proposal:** When a proposal is created, it requires future processing to manage the voting period, tally votes, and finalize the decision. The fee associated with creating a proposal is used to cover the cost of this automation.

- **Creating a Post Consensus:** Similar to proposals, creating a post consensus requires ongoing monitoring and automated execution. The fee for this action supports the automated systems that ensure decisions are processed accurately and transparently.

## How are Fees collected?
- All fees are collected by a fund contract, which immediatly swaps native token for LINK, to be used by Chainlink Automation Executions. All fees are stored in the respective automation jobs for Communities, Community Conesnsus, and Post Conesnsus contracts. No fees for these functions are held by owners of the contracts.

**IMPROTANT** These Fees are collected and shared in a pool, and not tied directly to upkeeps. Fees are nonrefundable. Please be aware that price volatility may affect the availability of funds required to process your upkeep. In such cases, your upkeep may not be automatically executed. However, you retain the option to manually process your proposal/post consnsus. This is a limitiation of Automation Execution, which can not tie direct fees to transactions.

### Chainlink Automation and Why It’s Necessary

These fees are linked to the use of **Chainlink Automation**, which powers the automated processes on tgether. Chainlink Automation allows us to trigger actions and events in a decentralized way, without relying on centralized servers or administrators. By using Chainlink, we can maintain a completely decentralized platform where every process—from voting to finalizing decisions—happens trustlessly and transparently.

In short, these fees are not just charges—they’re essential contributions to keeping the platform fully decentralized and ensuring that decisions are handled in a fair, transparent, and autonomous manner.
[See how we we do it!](/docs/Developer-Docs/chainlink-automation)

## Conclusion

Web3 is at the core of tgether’s mission to provide a decentralized, trustless platform for consensus. By leveraging blockchain and charging fees for key operations, we ensure that the platform remains sustainable and aligned with the principles of decentralization. We’re committed to providing communities with a space where they can govern themselves without outside interference, relying solely on transparent processes and immutable data.

Ready to dive deeper into how tgether works? Check out our [Developer Docs](../Developer-Docs/getting-started.md) to learn more.
